@@ -1,9 +1,12 @@
 # Default Test::Mini Output Logger.
 package Test::Mini::Logger::TAP;
-use base 'Test::Mini::Logger';
+
+use 5.006;
 use strict;
 use warnings;
 
+use parent 'Test::Mini::Logger';
+
 sub new {
     my ($class, %args) = @_;
     return $class->SUPER::new(test_counter => 0, %args);
